.btn.red {
  background-color: hsl(8, 76%, 30%) !important;
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#e0381e", endColorstr="#862112");
  background-image: -khtml-gradient(linear, left top, left bottom, from(#e0381e), to(#862112));
  background-image: -moz-linear-gradient(top, #e0381e, #862112);
  background-image: -ms-linear-gradient(top, #e0381e, #862112);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #e0381e), color-stop(100%, #862112));
  background-image: -webkit-linear-gradient(top, #e0381e, #862112);
  background-image: -o-linear-gradient(top, #e0381e, #862112);
  background-image: linear-gradient(#e0381e, #862112);
  border-color: #862112 #862112 hsl(8, 76%, 25%);
  color: #fff !important;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.33);
  -webkit-font-smoothing: antialiased;
  height: 34px;
}

.btn.blue {
  background-color: hsl(201, 100%, 30%) !important;
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#00a5ff", endColorstr="#006399");
  background-image: -khtml-gradient(linear, left top, left bottom, from(#00a5ff), to(#006399));
  background-image: -moz-linear-gradient(top, #00a5ff, #006399);
  background-image: -ms-linear-gradient(top, #00a5ff, #006399);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #00a5ff), color-stop(100%, #006399));
  background-image: -webkit-linear-gradient(top, #00a5ff, #006399);
  background-image: -o-linear-gradient(top, #00a5ff, #006399);
  background-image: linear-gradient(#00a5ff, #006399);
  border-color: #006399 #006399 hsl(201, 100%, 25%);
  color: #fff !important;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.33);
  -webkit-font-smoothing: antialiased;
  height: 34px;
}

.btn.green {
  background-color: hsl(97, 68%, 30%) !important;
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#6bd628", endColorstr="#408018");
  background-image: -khtml-gradient(linear, left top, left bottom, from(#6bd628), to(#408018));
  background-image: -moz-linear-gradient(top, #6bd628, #408018);
  background-image: -ms-linear-gradient(top, #6bd628, #408018);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #6bd628), color-stop(100%, #408018));
  background-image: -webkit-linear-gradient(top, #6bd628, #408018);
  background-image: -o-linear-gradient(top, #6bd628, #408018);
  background-image: linear-gradient(#6bd628, #408018);
  border-color: #408018 #408018 hsl(97, 68%, 25%);
  color: #fff !important;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.33);
  -webkit-font-smoothing: antialiased;
  height: 34px;
}

.top-buffer { margin-top:30px; }
.bottom-buffer { margin-bottom:30px; }

div#footer {
        position:fixed;
        bottom: 0px;
        padding-top: 10px;
        border-top: 1px solid gray;
        width: 100%;
        z-index: 1;
        background-color: #f5f5f5;
        font-size: 12px;
        text-align: center;
}
