#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pytest
import sys

import dnscherry



def add_record(br, key, value, ttl, rtype):
    pass

def del_records(br, key, value, ttl, rtype):
    pass

def get_zone(zone, key, host):
    pass

class TestForm(object):

   def conect(self):
       pass

   def del_records(self):
       pass

   def del_none_existing_record(self):
       pass

   def get_record(self):
       pass

   def get_wrong_zone(self):
       pass

   def add_faulty_record(self):
       pass

   def add_record(self):
       pass
#            assert res == expected

